@@ -1,10 +1,11 @@
-# Copyrights 2003,2004,2007 by Mark Overmeer <perl@overmeer.net>.
+# Copyrights 2003-2017 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see Changes.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.02.
+# Pod stripped from pm file by OODoc 2.02.
 package Mail::Identity;
 use vars '$VERSION';
-$VERSION = '0.92';
+$VERSION = '0.98';
+
 use base 'User::Identity::Item';
 
 use strict;
@@ -37,7 +38,7 @@ sub init($)
 
 
 sub from($)
-{   my ($class, $other) = @_;
+{   my ($class, $other) = (shift, shift);
     return $other if $other->isa(__PACKAGE__);
 
     if($other->isa('Mail::Address'))
